@@ -3,10 +3,14 @@
 """Generate knowledge graphs with interesting geometries, like lattices."""
 
 from .api import (  # noqa:F401
-    from_tuples,
+    ChainFactory,
+    CircleFactory,
+    HexagonalGrid2DFactory,
+    LineFactory,
+    SquareGrid2DFactory,
+    chain_factory,
+    circle_factory,
     hex_grid_factory,
-    iter_hex_grid_triples,
-    iter_square_grid_triples,
     line_factory,
     square_grid_factory,
 )
